@@ -29,4 +29,15 @@ def choose(mode: str = "list", json_file: str = "", info: str = "", name: list =
     elif mode == "json":
         return heframework.src.choose_return.json_mode(json_file, info).list()
     else:
-        return 25003
\ No newline at end of file
+        return 25003
+
+
+# refresh_show框架
+class refresh_show:
+    def __init__(self, title:str="", geometry:str=""):
+        import heframework.src.refresh
+        show = heframework.src.refresh.show(title, geometry)
+        self.show=show
+    
+    def refresh(self, message:str=""):
+        return self.show.update(message)
